pylbm.Scheme.compute\_amplification\_matrix\_relaxation
=======================================================

.. currentmodule:: pylbm

.. automethod:: Scheme.compute_amplification_matrix_relaxation